
/* 
 * Copyright (c) 1993-2005 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/


#ifndef imu_TCLSERV_CLIENT_ERROR_H
#define imu_TCLSERV_CLIENT_ERROR_H

#include <server/imuError.h>

/* -- MODULES ERRORS -------------------------------------------------- */

enum imu_error {
	E_imu_OK					  			= 0,

	/* module errors */
	E_imu_LIB_ERROR                      = S_imu_LIB_ERROR,
	E_imu_NOT_FOUND                      = S_imu_NOT_FOUND,
	E_imu_COMP_FAILED                    = S_imu_COMP_FAILED,
	E_imu_BAD_PARAMS                     = S_imu_BAD_PARAMS,
	E_imu_CANNOT_READ_SERIAL             = S_imu_CANNOT_READ_SERIAL,
	E_imu_ENOTINIT                       = S_imu_ENOTINIT,
	E_imu_EINUSE                         = S_imu_EINUSE,
	E_imu_EINVAL                         = S_imu_EINVAL,
	E_imu_ENOENT                         = S_imu_ENOENT,
	E_imu_ENOMEM                         = S_imu_ENOMEM,


	/* std errors */
	E_imu_ACTIVITY_INTERRUPTED           = S_imu_stdGenoM_ACTIVITY_INTERRUPTED,
	E_imu_TOO_MANY_ACTIVITIES            = S_imu_stdGenoM_TOO_MANY_ACTIVITIES,
	E_imu_ACTIVITY_FAILED                = S_imu_stdGenoM_ACTIVITY_FAILED,
	E_imu_WAIT_ABORT_ZOMBIE_ACTIVITY     = S_imu_stdGenoM_WAIT_ABORT_ZOMBIE_ACTIVITY,
	E_imu_UNKNOWN_ACTIVITY               = S_imu_stdGenoM_UNKNOWN_ACTIVITY,
	E_imu_FORBIDDEN_ACTIVITY_TRANSITION  = S_imu_stdGenoM_FORBIDDEN_ACTIVITY_TRANSITION,
	E_imu_SYSTEM_ERROR                   = S_imu_stdGenoM_SYSTEM_ERROR,
	E_imu_ACTIVITY_ALREADY_ENDED         = S_imu_stdGenoM_ACTIVITY_ALREADY_ENDED,
	E_imu_WAIT_INIT_RQST                 = S_imu_stdGenoM_WAIT_INIT_RQST,
	E_imu_CONTROL_CODEL_ERROR            = S_imu_stdGenoM_CONTROL_CODEL_ERROR,
	E_imu_EXEC_TASK_SUSPENDED            = S_imu_stdGenoM_EXEC_TASK_SUSPENDED,
	E_imu_BAD_BLOCK_TYPE                 = S_imu_stdGenoM_BAD_BLOCK_TYPE,
	E_imu_BAD_POSTER_TYPE                = S_imu_stdGenoM_BAD_POSTER_TYPE,

};

typedef enum imu_error imu_error_t;

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Take an error string in parameter, and try to get the error index associated
 * to this string
 * Returns -1 in failure case (and err is not set)
 * Returns 0 in success case (and err has a sensitive value)
 */
int imu_decode_error(const char* str, int *err);

/*
 * Take an integer representing an error, and try to get its textual
 * representation, in the imu context.
 *
 * Returns NULL in case of failure
 */
const char* imu_error_str(int err);

#ifdef __cplusplus
}
#endif


/*-------------------------- end file loading ---------------------------*/
#endif
